"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isBlacklisted(key, fullPath, keys, regex) {
    if (keys.has(key)) {
        return true;
    }
    for (const reg of regex) {
        if (reg.test(fullPath)) {
            return true;
        }
    }
    return false;
}
exports.isBlacklisted = isBlacklisted;
function _sanitize(obj, keys, regex, replaceWith, path, seenObjects) {
    if (seenObjects.has(obj)) {
        return seenObjects.get(obj);
    }
    if (Array.isArray(obj)) {
        const newPath = path + '[]';
        const newArray = new Array(obj.length);
        seenObjects.set(obj, newArray);
        obj.forEach((entry, index) => {
            newArray[index] = _sanitize(entry, keys, regex, replaceWith, newPath, seenObjects);
        });
        return newArray;
    }
    if (typeof obj === 'object') {
        const newObj = {};
        seenObjects.set(obj, newObj);
        // tslint:disable-next-line:forin
        for (const key in obj) {
            const prefix = path ? `${path}.` : '';
            const fullPath = prefix + key;
            const val = isBlacklisted(key, fullPath, keys, regex)
                ? replaceWith
                : _sanitize(obj[key], keys, regex, replaceWith, fullPath, seenObjects);
            newObj[key] = val;
        }
        return newObj;
    }
    return obj;
}
function sanitize(obj, opts = {}, path = '') {
    const { replaceWith = '[redacted]', keys = [], regex = [] } = opts;
    const seenObjects = new WeakMap();
    return _sanitize(obj, new Set(keys), regex, replaceWith, path, seenObjects);
}
exports.sanitize = sanitize;
exports.default = sanitize;
//# sourceMappingURL=index.js.map